@@ -1,5 +1,6 @@
 #include <stdio.h>
 #include <stdlib.h>
+#include <locale.h>
 #include <verbiste/c-api.h>
 
 
@@ -10,15 +11,6 @@ int main(int argc, char *argv[])
     const char *libdatadir;
     char conjFN[512], verbsFN[512];
 
-    libdatadir = getenv("LIBDATADIR");
-    if (libdatadir == NULL)
-        libdatadir = LIBDATADIR;
-
-    snprintf(conjFN, sizeof(conjFN), "%s/conjugation-fr.xml", libdatadir);
-    snprintf(verbsFN, sizeof(verbsFN), "%s/verbs-fr.xml", libdatadir);
-
-    verbiste_init(conjFN, verbsFN, "fr");
-
     if (argc < 2)
     {
         printf("deconjugator.c: demo of the C API of Verbiste\n");
@@ -27,6 +19,19 @@ int main(int argc, char *argv[])
         return EXIT_FAILURE;
     }
 
+    setlocale(LC_CTYPE, "");  // necessary on Solaris
+    libdatadir = getenv("LIBDATADIR");
+    if (libdatadir == NULL)
+        libdatadir = LIBDATADIR;
+
+    snprintf(conjFN, sizeof(conjFN), "%s/conjugation-fr.xml", libdatadir);
+    snprintf(verbsFN, sizeof(verbsFN), "%s/verbs-fr.xml", libdatadir);
+
+    if (verbiste_init(conjFN, verbsFN, "fr") != 0)
+    {
+        printf("deconjugator.c: failed to initialize Verbiste.\n");
+        return EXIT_FAILURE;
+    }
 
     vec = verbiste_deconjugate(argv[1]);
 
