@@ -1,4 +1,4 @@
-/*  $Id: Command.h,v 1.24 2016/11/20 07:26:34 sarrazip Exp $
+/*  $Id: Command.h,v 1.25 2017/08/29 01:47:43 sarrazip Exp $
     Command.h - Abstract command-line driver
 
     verbiste - French conjugation system
@@ -61,7 +61,7 @@ public:
     */
     Command(const std::string &conjugationFilename,
             const std::string &verbsFilename,
-            FrenchVerbDictionary::Language lang) throw (std::logic_error);
+            FrenchVerbDictionary::Language lang);
 
     /** Destroys the Verbiste dictionary object.
     */
@@ -73,23 +73,21 @@ public:
         They are converted to lower-case and passed to the processInputWord()
         method, which must be overridden by a class derived from this one.
     */
-    int run(int argc, char *argv[]) throw();
+    int run(int argc, char *argv[]);
 
     /** Returns a reference to the Verbiste dictionary object.
         @throws        std::logic_error error message indicating that
                                         the constructor failed to create
                                         the dictionary object
     */
-    const FrenchVerbDictionary &getFrenchVerbDictionary() const
-                                        throw (std::logic_error);
+    const FrenchVerbDictionary &getFrenchVerbDictionary() const;
 
     /** Returns a reference to the Verbiste dictionary object.
         @throws        std::logic_error error message indicating that
                                         the constructor failed to create
                                         the dictionary object
     */
-    FrenchVerbDictionary &getFrenchVerbDictionary()
-                                        throw (std::logic_error);
+    FrenchVerbDictionary &getFrenchVerbDictionary();
 
     /** Prints the name of every known verb to the designated text stream.
         Each printed infinitive is separated by a newline sequence.
@@ -98,7 +96,7 @@ public:
                                         the constructor failed to create
                                         the dictionary object
     */
-    int listAllInfinitives(std::ostream &out) const throw (std::logic_error);
+    int listAllInfinitives(std::ostream &out) const;
 
     /** Returns the value of the named environment variable.
         @param      name                non-empty name of the variable
